'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.noop = noop;
exports.getSelectedBlock = getSelectedBlock;
exports.getToggleStyleFunc = getToggleStyleFunc;
exports.findEntities = findEntities;
exports.getSelectionText = getSelectionText;
exports.getToggleBlockFunc = getToggleBlockFunc;
exports.getCurrentEntity = getCurrentEntity;

var _draftJs = require('draft-js');

function noop(args) {}
function getSelectedBlock(editorState) {
    var currentContent = editorState.getCurrentContent();
    var selection = editorState.getSelection();
    return currentContent.getBlockForKey(selection.getStartKey());
}
function getToggleStyleFunc(callbacks) {
    return function toggleStyle(styleName) {
        var getEditorState = callbacks.getEditorState;
        var setEditorState = callbacks.setEditorState;

        setEditorState(_draftJs.RichUtils.toggleInlineStyle(getEditorState(), styleName));
    };
}
function findEntities(entityType) {
    return function findEntitiesFunc(contentBlock, callback) {
        contentBlock.findEntityRanges(function (character) {
            var entityKey = character.getEntity();
            return entityKey !== null && _draftJs.Entity.get(entityKey).getType() === entityType;
        }, callback);
    };
}
function getSelectionText(editorState, selection) {
    var anchorKey = selection.getAnchorKey();
    var currentContent = editorState.getCurrentContent();
    var currentBlock = currentContent.getBlockForKey(anchorKey);
    return currentBlock.getText();
}
function getToggleBlockFunc(callbacks) {
    return function toggleBlock(entityType) {
        var entityMode = arguments.length <= 1 || arguments[1] === undefined ? 'MUTABLE' : arguments[1];
        var getEditorState = callbacks.getEditorState;
        var setEditorState = callbacks.setEditorState;

        var editorState = getEditorState();
        var selection = editorState.getSelection();
        var entityKey = null;
        var currentEntity = getCurrentEntity(editorState);
        if (!currentEntity || _draftJs.Entity.get(currentEntity).getType() !== entityType) {
            entityKey = _draftJs.Entity.create(entityType, entityMode, {});
        }
        var replacedContent = _draftJs.Modifier.applyEntity(editorState.getCurrentContent(), selection, entityKey);
        return setEditorState(_draftJs.EditorState.push(editorState, replacedContent, 'toggle-block'));
    };
}
function getCurrentEntity(editorState) {
    var entity = void 0;
    var selection = editorState.getSelection();
    var start = selection.getStartOffset();
    var end = selection.getEndOffset();
    if (start === end && start === 0) {
        end = -1;
    } else if (start === end) {
        start = start - 1;
    }
    var block = getSelectedBlock(editorState);
    for (var i = start; i < end; i++) {
        var currentEntity = block.getEntityAt(i);
        if (!currentEntity) {
            entity = undefined;
            break;
        }
        if (i === start) {
            entity = currentEntity;
        } else {
            if (entity !== currentEntity) {
                entity = undefined;
                break;
            }
        }
    }
    return entity;
}